-- UP script for initial-schema (20190214122514)
create extension if not exists "uuid-ossp";

create table "users" (
  id uuid default uuid_generate_v4() primary key,
  display_name varchar not null,
  email varchar not null unique,
  hashed_pwd varchar not null,
  salt varchar not null,
  is_admin boolean not null default false
);

create table "api_tokens" (
  id uuid default uuid_generate_v4() primary key,
  user_id uuid not null references users (id) on delete cascade on update cascade,
  name varchar not null,
  created timestamp(0) with time zone not null default current_timestamp,
  expires timestamp(0) with time zone default null,
  hashed_token varchar not null
);

create table "measures" (
  id uuid default uuid_generate_v4() primary key,
  user_id uuid not null references users (id) on delete cascade on update cascade,
  slug varchar not null,
  name varchar not null,
  description varchar not null default '',
  config jsonb not null default '{}'::json,
  unique(user_id, slug)
);

create table "measurements" (
  id uuid default uuid_generate_v4() primary key,
  measure_id uuid not null references measures (id) on delete cascade on update cascade,
  value integer not null,
  "timestamp" timestamp(0) with time zone not null default current_timestamp,
  ext_data jsonb not null default '{}'::json
);

create table client_log_entries (
  id serial primary key,
  user_id uuid not null references users (id),
  "level" varchar not null,
  "scope" varchar not null,
  message varchar not null,
  stacktrace varchar not null,
  "timestamp" timestamp(0) with time zone not null default current_timestamp
);

create index client_log_entries_by_level on client_log_entries ("level");
