import {
  Module,
  MutationAction,
  VuexModule
} from 'vuex-module-decorators';
import { LoginSubmit, User } from '@/models';
import api from '@/services/pm-api-client';
import { logService } from '@/services/logging';
import { authStore } from '@/store';

const logger = logService.getLogger('/store-modules/user');

@Module({ namespaced: true, name: 'user' })
export class UserStoreModule extends VuexModule {
  public user: User | null = null;
  public users: User[] = [];

  @MutationAction({ mutate: ['user'], rawError: true })
  public async fetchUser() {
    logger.trace('Fetching current user record.');
    return { user: await api.getUser() };
  }

  @MutationAction({ mutate: ['users'] })
  public async fetchAllUsers() {
    return { users: await api.getAllUsers() };
  }

  @MutationAction({ mutate: ['users'] })
  public async createUser(user: User) {
    const newUser = await api.createUser(user);
    return { users: this.users.concat([user]) };
  }

  @MutationAction({ mutate: ['users'] })
  public async deleteUser(userId: string) {
    await api.deleteUser(userId);
    return { users: this.users.filter((u) => u.id !== userId) };
  }
}
